@@ -27,7 +27,7 @@
 #' \bold{Degrees of freedom}
 #'
 #' Power is calculated using the \emph{t} distribution with non-centrality parameter \eqn{b/se},
-#' and DFs are either based on a the between-subjects or between-cluster \emph{dfs}, or using Satterthwaite's approximation.
+#' and \emph{dfs} are either based on a the between-subjects or between-cluster \emph{dfs}, or using Satterthwaite's approximation.
 #' For the "between" method, \eqn{N_3 - 2} is used for three-level models, and \eqn{N_2 - 2} for two-level models,
 #' where \eqn{N_3} and \eqn{N_2} is the total number of clusters and subjects in both arms.
 #'
@@ -171,7 +171,7 @@ print.plcp_power_3lvl <- function(x, ...) {
    }
     if(partially_nested) {
         if(is.null(x$note)) {
-            x$note <- "Study is partially nested. Clustering only in treatment arm. Cohen's d is standardized using the control group's pretest SD."
+            x$note <- "Study is partially nested. Clustering only in treatment arm."
         } else {
             x$note <- paste(x$note, "Study is partially nested. Clustering only in treatment arm", sep = "\n      ")
         }
@@ -180,7 +180,7 @@ print.plcp_power_3lvl <- function(x, ...) {
     print(x, ...)
 
     if(partially_nested & !.p$satterth) {
-        message("N.B: Satterthwaite DFs are recommended for partially-nested models, or calculate power with 'simulate.plcp'")
+        message("N.B: Satterthwaite dfs are recommended for partially-nested models, or calculate power with 'simulate.plcp'")
     }
 }
 
